# AUTOGENERATED! DO NOT EDIT! File to edit: ../../../notebooks/utils/05_naming.ipynb.

# %% auto 0
__all__ = ['concat2array', 'standardize_plasma_data']

# %% ../../../notebooks/utils/05_naming.ipynb 2
import polars as pl
from space_analysis.meta import PlasmaDataset
from ..naming import DENSITY_COL, VELOCITY_COL, TEMP_COL

# %% ../../../notebooks/utils/05_naming.ipynb 3
def concat2array(data: pl.LazyFrame, cols: list, name: str, drop: bool = True):
    data = data.with_columns(pl.concat_list(*cols).list.to_array(len(cols)).alias(name))
    return data.drop(cols) if drop else data


def standardize_plasma_data(data: pl.LazyFrame, meta: PlasmaDataset):
    """
    Standardize plasma data columns across different datasets.

    Notes: meta will be updated with the new column names
    """

    mapping = dict()
    if meta.density_col:
        mapping[meta.density_col] = DENSITY_COL
    if meta.temperature_col:
        mapping[meta.temperature_col] = TEMP_COL

    v_cols = meta.velocity_cols
    if v_cols:
        if isinstance(v_cols, list):
            data = concat2array(data, v_cols, VELOCITY_COL)
        else:
            mapping[v_cols] = VELOCITY_COL
    return data.rename(mapping)
